Available Extensions
====================

It is possible to write packages for extending ``outgoing`` with support for
further sending methods and password schemes.  See :ref:`writing-extensions`
for how to do so.

If you develop an extension package, please submit a PR so it can be listed on
this page!

Sending Methods
---------------

- outgoing-mailgun__ — Supports sending e-mail via Mailgun__

  __ https://github.com/jwodder/outgoing-mailgun
  __ https://www.mailgun.com


Password Schemes
----------------

None yet.  Be the first!
